@@ -17,18 +17,33 @@ import logging
 from datetime import timedelta
 from json import loads
 from time import sleep
-from typing import Sequence, Optional, List, Dict, Union
+from typing import Sequence, Optional, List, Dict, Union, Any
 
-from VertFlow.constants import ALL_CLOUD_RUN_REGIONS
+from src.constants import ALL_CLOUD_RUN_REGIONS
 
 import requests_cache
-from geocoder import ip, distance
+from geocoder import ip, distance, osm
 
 logging.getLogger("geocoder").setLevel(logging.WARNING)
 logging.getLogger("requests_cache").setLevel(logging.WARNING)
 logging.getLogger("googleapiclient").setLevel(logging.WARNING)
 
 
+class Geolocation:
+    @classmethod
+    def here(cls) -> Dict[str, float]:
+        geolocation = ip("me").latlng
+        return {"lat": geolocation[0], "lon": geolocation[1]}
+
+    @classmethod
+    def of(cls, location_name: str) -> Dict[str, float]:
+        try:
+            geojson = osm(location_name).geojson["features"][0]["properties"]
+            return {"lat": geojson["lat"], "lon": geojson["lng"]}
+        except IndexError:
+            raise LookupError(f"Could not geolocate {location_name}.")
+
+
 class CloudRunRegions:
     def __init__(self, project_id: str, co2_signal_api_key: str) -> None:
         """
@@ -38,8 +53,7 @@ class CloudRunRegions:
         """
         self.project_id = project_id
         self.co2_signal_api_key = co2_signal_api_key
-
-        self.__all = ALL_CLOUD_RUN_REGIONS
+        self.all = ALL_CLOUD_RUN_REGIONS
 
     @property
     def closest(self) -> Dict[str, Union[str, float, int]]:
@@ -47,9 +61,7 @@ class CloudRunRegions:
         Return the Google Cloud region closest to this machine.
         :return: A dictionary of data about the closest region.
         """
-        geolocation = ip("me").latlng
-
-        here = {"lat": geolocation[0], "lon": geolocation[1]}
+        here = Geolocation.here()
 
         distances_from_here = [
             {
@@ -62,7 +74,7 @@ class CloudRunRegions:
                     )
                 },
             }
-            for region in self.__all
+            for region in self.all
         ]
 
         closest = min(
@@ -71,7 +83,7 @@ class CloudRunRegions:
 
         return {
             **closest,
-            **{"carbon_intensity": self.__carbon_intensity(str(closest["id"]))},
+            **{"carbon_intensity": self._carbon_intensity(str(closest["id"]))},
         }
 
     def greenest(
@@ -86,14 +98,14 @@ class CloudRunRegions:
 
         if candidate_regions:
             assert set(candidate_regions).issubset(
-                {region["id"] for region in self.__all}
-            ), f"Invalid region(s) provided. Allowed Cloud Run regions: {self.__all}"
+                {region["id"] for region in self.all}
+            ), f"Invalid region(s) provided. Allowed Cloud Run regions: {self.all}"
             regions = [
-                region for region in self.__all if region["id"] in candidate_regions
+                region for region in self.all if region["id"] in candidate_regions
             ]
 
         else:
-            regions = self.__all
+            regions = self.all
 
         carbon_intensity_for_candidate_regions: List[
             Dict[str, Union[str, float, int]]
@@ -105,7 +117,7 @@ class CloudRunRegions:
                     {
                         **region,
                         **{
-                            "carbon_intensity": self.__carbon_intensity(
+                            "carbon_intensity": self._carbon_intensity(
                                 str(region["id"])
                             )
                         },
@@ -125,7 +137,7 @@ class CloudRunRegions:
             carbon_intensity_for_candidate_regions, key=lambda x: x["carbon_intensity"]
         )
 
-    def __carbon_intensity(self, region: str) -> int:
+    def _carbon_intensity(self, region: str) -> int:
         """
         Return the carbon intensity of a Google Cloud Region with a given ID, using data from CO2 Signal API.
         Uses locally-cached API data where possible, to prevent hitting rate limits.
@@ -133,7 +145,7 @@ class CloudRunRegions:
         :return: The carbon intensity (in gCO2eq/kWh)
         """
         sleep(1)  # To avoid API rate limits.
-        region_obj = [r for r in self.__all if region == r["id"]][0]
+        region_obj = [r for r in self.all if region == r["id"]][0]
 
         try:
             session = requests_cache.CachedSession(
